@@ -20,6 +20,7 @@ from nexusformat.nexus import (NeXusError, NXdata, NXentry, NXfield, NXgroup,
 
 from .pyqt import QtCore, QtGui, QtWidgets
 from .utils import display_message, natural_sort, modification_time
+from .widgets import NXSortModel
 from nexusformat.nexus import *
 
 
@@ -258,17 +259,6 @@ class NXTreeItem(QtGui.QStandardItem):
                 yield item
 
 
-class NXSortModel(QtCore.QSortFilterProxyModel):
-
-    def __init__(self, parent=None):
-        super(NXSortModel, self).__init__(parent)
-
-    def lessThan(self, left, right):
-        left_text = self.sourceModel().itemFromIndex(left).text()
-        right_text = self.sourceModel().itemFromIndex(right).text()
-        return natural_sort(left_text) < natural_sort(right_text)
-
-    
 class NXTreeView(QtWidgets.QTreeView):
 
     def __init__(self, tree, parent):
@@ -382,12 +372,8 @@ class NXTreeView(QtWidgets.QTreeView):
             self.mainwindow.copydata_action.setEnabled(True)
             if isinstance(node, NXlink):
                 self.mainwindow.link_action.setEnabled(True)
-            try:
-                if (isinstance(node, NXdata) and
-                    node.plottable_data.nxsignal.plot_rank == 1):
-                    self.mainwindow.export_action.setEnabled(True)
-            except Exception as error:
-                pass
+            if isinstance(node, NXdata):
+                self.mainwindow.export_action.setEnabled(True)
             if node.is_modifiable():
                 if isinstance(node, NXgroup):
                     self.mainwindow.initialize_action.setEnabled(True)
@@ -403,7 +389,8 @@ class NXTreeView(QtWidgets.QTreeView):
                     self.mainwindow.signal_action.setEnabled(True)
             try:
                 if ((isinstance(node, NXdata) and node.plot_rank == 1) or
-                    (isinstance(node, NXgroup) and 'fit' in node)):
+                    (isinstance(node, NXgroup) and 
+                    ('fit' in node or 'model' in node))):
                     self.mainwindow.fit_action.setEnabled(True)
             except Exception as error:
                 pass
